EureConfig

Struct EureConfig 

pub struct EureConfig {
    pub targets: HashMap<String, Target>,
}
The main Eure configuration.

Fields

targets: HashMap<String, Target>

Check targets (name -> target definition).

Implementations

Source

impl EureConfig

pub fn find_config_file(start_dir: &Path) -> Option<PathBuf>

Find the configuration file by searching upward from the given directory.

pub fn get_target(&self, name: &str) -> Option<&Target>

Get a target by name.

pub fn target_names(&self) -> impl Iterator<Item = &str>

Get all target names.

pub fn schema_for_path( &self, file_path: &Path, config_dir: &Path, ) -> Option<PathBuf>

Find the schema for a file path by matching against target globs.

Returns the first matching target’s schema path, if any.